@@ -6,7 +6,7 @@ distinct.tbl_graph <- function(.data, ..., .keep_all = FALSE) {
   .register_graph_context(.data)
   d_tmp <- as_tibble(.data)
   if ('.tbl_graph_index' %in% names(d_tmp)) {
-    stop('The attribute name ".tbl_graph_index" is reserved', call. = FALSE)
+    cli::cli_abort('The attribute name {.field .tbl_graph_index} is reserved')
   }
   orig_ind <- seq_len(nrow(d_tmp))
   dot_list <- quos(..., .named = TRUE)
