@@ -424,7 +424,7 @@ map_local_dbl <- function(order = 1, mode = 'all', mindist = 0, .f, ...) {
 #' @importFrom igraph bfs
 #' @importFrom tibble tibble
 bfs_df <- function(graph, root, mode, unreachable) {
-  search <- bfs(graph = graph, root = root, neimode = mode, unreachable = unreachable,
+  search <- bfs(graph = graph, root = root, mode = mode, unreachable = unreachable,
                 order = TRUE, rank = TRUE, father = TRUE, pred = TRUE,
                 succ = TRUE, dist = TRUE)
   nodes <- seq_along(search$order)
@@ -441,7 +441,7 @@ bfs_df <- function(graph, root, mode, unreachable) {
 #' @importFrom igraph dfs
 #' @importFrom tibble tibble
 dfs_df <- function(graph, root, mode, unreachable) {
-  search <- dfs(graph = graph, root = root, neimode = mode, unreachable = unreachable,
+  search <- dfs(graph = graph, root = root, mode = mode, unreachable = unreachable,
                 order = TRUE, order.out = TRUE, father = TRUE, dist = TRUE)
   nodes <- seq_along(search$order)
   tibble(
@@ -475,7 +475,7 @@ get_offspring <- function(parent, order) {
   offspring <- rep(list(integer(0)), length(parent))
   direct_offspring <- split(seq_along(parent), parent)
   offspring[as.integer(names(direct_offspring))] <- direct_offspring
-  offspring <- collect_offspring(offspring, rev(order))
+  offspring <- collect_offspring(offspring, as.integer(rev(order)))
   lapply(offspring, function(x) x[order(match(x, order))])
 }
 
@@ -527,6 +527,7 @@ as_vector <- function(.x, .type = NULL){
     unlist(.x)
   }
   else {
-    stop("Cannot coerce values to ", deparse(substitute(.type)), call. = FALSE)
+    type <- deparse(substitute(.type))
+    cli::cli_abort("Cannot coerce values to {.cls {type}}")
   }
 }
