@@ -6,7 +6,7 @@ sample_n.tbl_graph <- function(tbl, size = 1, replace = FALSE, weight = NULL, .e
   d_tmp <- as_tibble(tbl)
   weight <- enquo(weight)
   if ('.tbl_graph_index' %in% names(d_tmp)) {
-    stop('The attribute name ".tbl_graph_index" is reserved', call. = FALSE)
+    cli::cli_abort('The attribute name {.field .tbl_graph_index} is reserved')
   }
   orig_ind <- seq_len(nrow(d_tmp))
   d_tmp$.tbl_graph_index <- orig_ind
