@@ -8,9 +8,10 @@ as_tibble.tbl_graph <- function(x, active = NULL, ...) {
     active,
     nodes = node_tibble(x),
     edges = edge_tibble(x),
-    stop('Unknown active element: ', active, '. Only nodes and edges supported', call. = FALSE)
+    cli::cli_abort('Unknown active element: {.val {active}}. Only nodes and edges supported')
   )
 }
+#' @export
 as_tibble.grouped_tbl_graph <- function(x, active = NULL, ...) {
   tbl <- NextMethod()
   if (is.null(active)) {
@@ -21,6 +22,10 @@ as_tibble.grouped_tbl_graph <- function(x, active = NULL, ...) {
   tbl
 }
 #' @export
+as_tibble.morphed_tbl_graph <- function(x, ...) {
+  as_tibble(crystallize(x))
+}
+#' @export
 tibble::as_tibble
 
 #' @importFrom magrittr %>%
